@@ -52,6 +52,7 @@ CombineReducerState = TypeVar(
     'CombineReducerState',
     bound=BaseCombineReducerState,
 )
+AnyAction = TypeVar('AnyAction', bound=BaseAction)
 
 
 def is_combine_reducer_action(action: BaseAction) -> TypeGuard[CombineReducerAction]:
@@ -61,7 +62,7 @@ def is_combine_reducer_action(action: BaseAction) -> TypeGuard[CombineReducerAct
 def combine_reducers(
     action_type: type[Action],  # noqa: ARG001
     state_type: type[CombineReducerState],
-    **reducers: ReducerType[State, Action],
+    **reducers: ReducerType[State, Any],
 ) -> tuple[ReducerType[CombineReducerState, Action], str]:
     _id = uuid.uuid4().hex
 
@@ -124,7 +125,10 @@ def combine_reducers(
                 )
 
         reducers_results = {
-            key: reducer(None if state is None else getattr(state, key), action)
+            key: reducer(
+                None if state is None else getattr(state, key),
+                action,
+            )
             for key, reducer in reducers.items()
         }
         result_state = state_class(
